@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.1.8'
+__version__ = '0.1.10'
 
 try:
     from importlib import import_module
@@ -33,14 +33,6 @@ from types import ModuleType
 
 LOGGER = getLogger(__name__)
 
-
-MESSAGE_HAS_BEEN_CALLED_AT_LEAST_ONCE = """{call_entry} should NEVER have been called,
-but has been called at least once."""
-MESSAGE_NO_CALLS = """
-Expected: {expected}
- but was: no patched function has been called.
-"""
-
 NEVER = 0
 
 _configurators = {}
@@ -269,7 +261,7 @@ class TargetHasBeenCalledWithDifferentArguments(AssertionError):
 Expected: {expected}
  but was: {actual}
 """
-    ADDITIONAL_CALL_ENTRIES = '          {actual}\n'
+    ADDITIONAL_CALL_ENTRIES = ' ' * 10 + '{actual}\n'
 
     def __init__(self, expected_call_entry, found_calls):
 
@@ -281,6 +273,28 @@ Expected: {expected}
         super(TargetHasBeenCalledWithDifferentArguments, self).__init__(error_message)
 
 
+class HasBeenCalledAtLeastOnceError(AssertionError):
+
+    MESSAGE_FORMAT = """{call_entry} should NEVER have been called,
+but has been called at least once."""
+
+    def __init__(self, call_entry):
+        error_message = self.MESSAGE_FORMAT.format(call_entry=call_entry)
+        super(HasBeenCalledAtLeastOnceError, self).__init__(error_message)
+
+
+class NoCallsStoredError(AssertionError):
+
+    MESSAGE_FORMAT = """
+Expected: {expected}
+ but was: no patched function has been called.
+"""
+
+    def __init__(self, expected_call_entry):
+        error_message = self.MESSAGE_FORMAT.format(expected=expected_call_entry)
+        super(NoCallsStoredError, self).__init__(error_message)
+
+
 class Verifier(FluentTarget):
 
     def __init__(self, target, times):
@@ -300,22 +314,30 @@ class Verifier(FluentTarget):
         return self
 
     def __call__(self, *arguments, **keyword_arguments):
-        if self._times == 0:
-            self._assert_never_called(*arguments, **keyword_arguments)
+        method_of_mock = getattr(self._target, self._attribute_name)
+        if isinstance(self._target, Mock) and isinstance(method_of_mock, Mock):
+            if self._times == NEVER:
+                call_entry = call(*arguments, **keyword_arguments)
+                if call_entry in method_of_mock.call_args_list:
+                    raise HasBeenCalledAtLeastOnceError(call_entry)
+            else:
+                method_of_mock.assert_called_with(*arguments, **keyword_arguments)
         else:
-            self._assert_called(*arguments, **keyword_arguments)
+            if self._times == NEVER:
+                self._assert_never_called(*arguments, **keyword_arguments)
+            else:
+                self._assert_called(*arguments, **keyword_arguments)
 
     def _assert_never_called(self, *arguments, **keyword_arguments):
         for call_entry in _call_entries:
             if call_entry.verify(self._target, self._attribute_name, arguments, keyword_arguments):
-                error_message = MESSAGE_HAS_BEEN_CALLED_AT_LEAST_ONCE.format(call_entry=call_entry)
-                raise AssertionError(error_message)
+                raise HasBeenCalledAtLeastOnceError(call_entry)
 
     def _assert_called(self, *arguments, **keyword_arguments):
         expected_call_entry = FluentCallEntry(self._target, self._attribute_name, arguments, keyword_arguments)
 
         if not _call_entries:
-            raise AssertionError(MESSAGE_NO_CALLS.format(expected=expected_call_entry))
+            raise NoCallsStoredError(expected_call_entry)
 
         for call_entry in _call_entries:
             if call_entry.verify(self._target, self._attribute_name, arguments, keyword_arguments):
